@@ -61,7 +61,7 @@
 #'                     logger       = "",
 #'                     filenameroot = "mydownload1",
 #'                     datafxns     = list(csv = reactiveVal(iris)),
-#'                     aspectratio  = 1)
+#'                     row_names    = FALSE)
 #'        # multiple download types
 #'        downloadFile(id           = "object_id2",
 #'                     logger       = "",
@@ -119,6 +119,14 @@ downloadFileButton <- function(id,
     file_button_ui
 }
 
+check_openxlsx2_availability <- function() {
+    length(find.package("openxlsx2", quiet = TRUE)) > 0
+}
+
+check_openxlsx_availability <- function() {
+    length(find.package("openxlsx", quiet = TRUE)) > 0
+}
+
 
 #' downloadFile module server function
 #'
@@ -137,6 +145,8 @@ downloadFileButton <- function(id,
 #' @param aspectratio the downloaded chart image width:height ratio (ex:
 #' 1 = square, 1.3 = 4:3, 0.5 = 1:2). Where not applicable for a download type
 #' it is ignored (e.g. data downloads).
+#' @param row_names logical value indicating whether row names are to be written
+#' for tabular data. Where not applicable for a download type it is ignored.
 #'
 #' @return no return value, called for downloading selected file type
 #'
@@ -174,7 +184,7 @@ downloadFileButton <- function(id,
 #'                     logger       = "",
 #'                     filenameroot = "mydownload1",
 #'                     datafxns     = list(csv = reactiveVal(iris)),
-#'                     aspectratio  = 1)
+#'                     row_names    = FALSE)
 #'        # multiple download types
 #'        downloadFile(id           = "object_id2",
 #'                     logger       = "",
@@ -189,7 +199,8 @@ downloadFile <- function(id,
                          logger       = NULL,
                          filenameroot = "download",
                          datafxns     = NULL,
-                         aspectratio  = 1) {
+                         aspectratio  = 1,
+                         row_names    = TRUE) {
     shiny::moduleServer(
         id,
         function(input, output, session) {
@@ -204,8 +215,12 @@ downloadFile <- function(id,
                 filename = shiny::reactive({paste(rootname(), "csv", sep = ".")}),
                 content  = function(file) {
                     if (!is.null(datafxns)) {
-                        writeFile("csv", datafxns$csv(), file, logger,
-                                  shiny::reactive({paste(rootname(), "csv", sep = ".")}))
+                        writeFile(type          = "csv",
+                                  data          = datafxns$csv(),
+                                  file          = file,
+                                  show_rownames = row_names,
+                                  logger        = logger,
+                                  filename      = shiny::reactive({paste(rootname(), "csv", sep = ".")}))
                     }
                 })
 
@@ -213,8 +228,12 @@ downloadFile <- function(id,
                 filename = shiny::reactive({paste(rootname(), "xlsx", sep = ".")}),
                 content  = function(file) {
                     if (!is.null(datafxns)) {
-                        writeFile("xlsx", datafxns$xlsx(), file, logger,
-                                  shiny::reactive({paste(rootname(), "xlsx", sep = ".")}))
+                        writeFile(type          = "xlsx",
+                                  data          = datafxns$xlsx(),
+                                  file          = file,
+                                  show_rownames = row_names,
+                                  logger        = logger,
+                                  filename      = shiny::reactive({paste(rootname(), "xlsx", sep = ".")}))
                     }
                 })
 
@@ -222,8 +241,12 @@ downloadFile <- function(id,
                 filename = shiny::reactive({paste(rootname(), "tsv", sep = ".")}),
                 content = function(file) {
                     if (!is.null(datafxns)) {
-                        writeFile("tsv", datafxns$tsv(), file, logger,
-                                  shiny::reactive({paste(rootname(), "tsv", sep = ".")}))
+                        writeFile(type          = "tsv",
+                                  data          = datafxns$tsv(),
+                                  file          = file,
+                                  show_rownames = row_names,
+                                  logger        = logger,
+                                  filename      = shiny::reactive({paste(rootname(), "tsv", sep = ".")}))
                     }
                 })
 
@@ -231,17 +254,31 @@ downloadFile <- function(id,
                 filename = shiny::reactive({paste(rootname(), "txt", sep = ".")}),
                 content = function(file) {
                     if (!is.null(datafxns)) {
-                        writeFile("txt", datafxns$txt(), file, logger,
-                                  shiny::reactive({paste(rootname(), "txt", sep = ".")}))
+                        writeFile(type          = "txt",
+                                  data          = datafxns$txt(),
+                                  file          = file,
+                                  show_rownames = row_names,
+                                  logger        = logger,
+                                  filename      = shiny::reactive({paste(rootname(), "txt", sep = ".")}))
                     }
                 })
 
-            # filename is expected to be a reactive expression
-            writeFile <- function(type, data, file, logger, filename) {
+
+            ## writeFile
+            ##
+            ## @param type type of file to write
+            ## @param data data to write
+            ## @param file file path to write to
+            ## @param show_rownames if TRUE, row names are written for tabular data
+            ## @param logger logger to use
+            ## @param filename name of downloaded file, expected to be a reactive expression
+            ##
+            ## @returns no return value
+            writeFile <- function(type, data, file, show_rownames, logger, filename) {
+                show_rownames <- isTRUE(show_rownames)
+
                 # tabular values
                 if ((type == "csv") || (type == "tsv")) {
-                    show_rownames <- attr(data, "show_rownames")
-                    show_rownames <- !is.null(show_rownames) && show_rownames
                     show_colnames <- TRUE
                     if (show_rownames) {
                         show_colnames <- NA
@@ -256,17 +293,32 @@ downloadFile <- function(id,
                 }
                 # excel file
                 else if (type == "xlsx") {
-                    if (length(find.package("openxlsx", quiet = TRUE) > 0)) {
-                        if ((inherits(data, "Workbook")) && ("openxlsx" %in% attributes(class(data)))) {
-                            openxlsx::saveWorkbook(data, file)
-                        } else {
-                            show_rownames <- attr(data, "show_rownames")
-                            openxlsx::write.xlsx(data, file,
-                                                 asTable   = TRUE,
-                                                 rowNames = !is.null(show_rownames) && show_rownames)
-                        }
+
+                    if (inherits(data, "wbWorkbook") && check_openxlsx2_availability()) {
+                        openxlsx2::wb_save(data, file)
+                    } else if (inherits(data, "Workbook") &&
+                               ("openxlsx" %in% attributes(class(data))) &&
+                               check_openxlsx_availability()) {
+                        openxlsx::saveWorkbook(data, file)
                     } else {
-                        writexl::write_xlsx(data, file)
+                        # tabular data
+                        if (check_openxlsx2_availability()) {
+                            openxlsx2::write_xlsx(data,
+                                                  file,
+                                                  as_table  = TRUE,
+                                                  row_names = show_rownames)
+                        } else if (check_openxlsx_availability()) {
+                            openxlsx::write.xlsx(data,
+                                                 file,
+                                                 asTable  = TRUE,
+                                                 rowNames = show_rownames)
+                        } else {
+                            if (show_rownames) {
+                                logwarn("Downloading with 'writexl', row names are not included",
+                                        logger = logger)
+                            }
+                            writexl::write_xlsx(data, file)
+                        }
                     }
                 }
                 # text file processing
@@ -274,7 +326,7 @@ downloadFile <- function(id,
                     if (inherits(data, "character")) {
                         writeLines(data, file)
                     } else if (is.data.frame(data) || is.matrix(data)) {
-                        utils::write.table(data, file)
+                        utils::write.table(data, file, row.names = show_rownames)
                     } else {
                         msg <- paste(type, "could not be processed")
                         logwarn(msg)
