@@ -168,11 +168,11 @@ table_downloader_box <- box(
              column(width = 6,
                     tags$dl(tags$dt("Setup"),
                             tags$li("Module should be configured in both UI and Server code"),
-                            tags$li("In your 'body_ui.R', place module UI part as follow: ",
+                            tags$li("In the 'body_ui.R' add the following lines:",
                                     blockQuote("downloadableTableUI('exampleDT1',
                                                                     list('csv', 'tsv'),
                                                                     'Download table data'))", color = "info")),
-                            tags$li("In your 'server_local.R', place module server part, ", tags$em("with the same id used with UI part"), ", as follow: ",
+                            tags$li("In the 'server_local.R' add the following lines (make sure the two use the same ID):",
                                     blockQuote("downloadableTable('exampleDT1',
                                                                   ss_userAction.Log,
                                                                   'exampletable',
@@ -186,6 +186,47 @@ table_downloader_box <- box(
 
 )
 
+
+react_table_box <- box(
+    id          = "react_downloader",
+    title       = "React Table Downloader",
+    status      = "info",
+    solidHeader = TRUE,
+    collapsible = TRUE,
+    width       = 12,
+    fluidRow(column(width = 6,
+                    tags$dl(tags$dt("Features"),
+                            tags$ul(tags$li("React table downloader module displays tabular data in rich formatted tables using the", tags$b("`reactable`"), "package"),
+                                    tags$li("downloadableReactTable returns a named reactive list that can be used in the application:",
+                                            tags$ul(tags$li(tags$b("selected_rows"), ": data.frame of current selected rows"),
+                                                    tags$li(tags$b("table_state"), ": a list of the current table state"))),
+                                    tags$li("Table data can be downloaded in different formats such as: ", tags$b("'csv'"),
+                                            ", ", tags$b("'tsv'"), ", ", tags$b("'txt'"), "and/or ", tags$b("'xlsx'")),
+                                    tags$li("User can customize downloadableReactTable modules using reactable package options."),
+                                    tags$li("For more information about table options please visit the",
+                                            tags$a("Reactable documentation", target = "_blank", href = "https://glin.github.io/reactable/"),
+                                            "site")
+                            ))),
+             column(width = 6,
+                    tags$dl(tags$dt("Setup"),
+                            tags$li("Module should be configured in both UI and Server code"),
+                            tags$li("In the 'body_ui.R' add the following lines:",
+                                    blockQuote("downloadableReactTableUI('exampleReactTable',
+                                                                         'Download react table data'))", color = "info")),
+                            tags$li("In the 'server_local.R' add the following lines (make sure the two use the same ID):",
+                                    blockQuote("downloadableReactTable('exampleReactTable',
+                                                                       ss_userAction.Log,
+                                                                       'exampletable',
+                                                                        list(csv = load_data3, tsv = load_data3))", color = "info")),
+                            tags$li("Review ", tags$b("?downloadableReactTableUI"), " and ", tags$b("?downloadableReactTable"), " for more information"),
+                            tags$li("Review below table for detailed example code")))),
+    fluidRow(column(width = 12,
+                    downloadableReactTableUI(id            = "exampleReactTable",
+                                             downloadtypes = list("csv", "tsv"),
+                                             hovertext     = "Download react table data")))
+
+)
+
 file_downloader_box <- box(
     id          = "file_downloader",
     title       = "File Downloader",
@@ -237,9 +278,9 @@ plot_downloader_box <- box(
              column(width = 6,
                     tags$dl(tags$dt("Setup"),
                             tags$ul(tags$li("Module should be configured in both the UI and Server code"),
-                                    tags$li("In your 'body_ui.R', place module UI part as follow: ",
+                                    tags$li("In the 'body_ui.R' add the following lines:",
                                             blockQuote("downloadablePlotUI('myplotID', c('png', 'csv'), 'Download Plot or Data', '300px'))", color = "info")),
-                                    tags$li("In your 'server_local.R', place module server part, ", tags$em("with the same id used with UI part"), ", as follow: ",
+                                    tags$li("In the 'server_local.R' add the following lines (make sure the two use the same ID):",
                                             blockQuote("downloadablePlot('myplotID',
                                                                   ss_userAction.Log,
                                                                   filenameroot = 'mydownload1',
@@ -297,6 +338,7 @@ reset_application_box <- box(
 
 
 periscope_modules <- tabItem(tabName = "periscope_modules",
+                             react_table_box,
                              table_downloader_box,
                              plot_downloader_box,
                              file_downloader_box,
