@@ -7,11 +7,7 @@ sample_log <- function(){
       "actions [2022-02-19 14:04:32] Application Reset requested by user.  Resetting in  5 seconds")
 }
 
-null_log <- function(){
-    NULL
-}
-
-empty_log <- function(){
+null_log <- function() {
     NULL
 }
 
@@ -26,24 +22,15 @@ test_that("logViewer - valid sample log", {
     testServer(logViewer,
                args = list(id = "myid", logger = sample_log),
                expr = {
-                   expect_snapshot_output(output$myid)
+                   expect_snapshot_output(output$"myid-reactTableOutputID")
                })
 })
 
 
-test_that("logViewer - null sample log", {
+test_that("logViewer - null log", {
     testServer(logViewer,
                args = list(id = "nullLogger", logger = null_log),
                expr = {
-                   expect_null(output$nullLogger)
-               })
-})
-
-
-test_that("logViewer - empty sample log", {
-    testServer(logViewer,
-               args = list(id = "emptyLogger", logger = empty_log),
-               expr = {
-                   expect_null(output$emptyLogger)
+                   expect_true(grepl('"x":null', output$"nullLogger-reactTableOutputID", fixed = TRUE))
                })
 })
